__title__ = 'vishap.defaults'
__author__ = 'Artur Barseghyan'
__copyright__ = 'Copyright (c) 2013 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'
__all__ = ('PLUGINS_DIR', 'CONTRIB_DIR', 'PLUGIN_MODULE_NAME', 'DEBUG')

PLUGINS_DIR = ('contrib', 'plugins')
CONTRIB_DIR =  ('contrib', 'apps')
PLUGIN_MODULE_NAME = 'vishap_plugin'

DEBUG = False
